@@ -19,6 +19,7 @@
 #include <QTextStream>
 #include <QMaemo5InformationBox>
 #include <QtMaemo5/QtMaemo5>
+#include <QDebug>
 
 MainWindow::MainWindow(QWidget *parent):
     QMainWindow(parent), ui(new Ui::MainWindow),
@@ -32,88 +33,128 @@ MainWindow::MainWindow(QWidget *parent):
 {
     ui->setupUi(this);
 
+    qDebug("Set Window");
     //Set Window
     this->setWindowTitle("FlopSwap");
     this->setAttribute(Qt::WA_Maemo5StackedWindow);
 
+    qDebug("Set Button Text");
     //Set Button Text
     ui->pushButtonSwap->setText(tr("Fresh Swap"));
     ui->pushButtonEject->setText(tr("Swap to Device"));
     ui->pushButtonEjectV->setText(tr("Swap to Device"));
     ui->pushButtonGet->setText(tr("Check"));
-    //ui->pushButtonSwapUsage->setText(tr("Check Status"));
 
+    qDebug("Set Button Icons");
     // Set Button Icons
     ui->pushButtonSwap->setIcon(QPixmap("/opt/flopswap/icons/refresh_icon&32.png"));
     ui->pushButtonEject->setIcon(QPixmap("/opt/flopswap/icons/eject_icon&32.png"));
     ui->pushButtonEjectV->setIcon(QPixmap("/opt/flopswap/icons/eject_icon&32.png"));
     ui->pushButtonGet->setIcon(QPixmap("/opt/flopswap/icons/info_icon&32.png"));
-    //ui->pushButtonSwapUsage->setIcon(QPixmap("/opt/flopswap/icons/checkbox_checked_icon&32.png"));
 
-    //Set Statusbar Font Size
+    qDebug("Setup Statusbar Font Size");
+    //Setup Statusbar Font Size
     QFont f = ui->labelStat->font();
-    f.setPointSize( f.pointSize() + 1 );
+    f.setPointSize( f.pointSize() + 2 );
     QFont g = ui->labelLocStat->font();
-    g.setPointSize( g.pointSize() + 1 );
+    g.setPointSize( g.pointSize() + 2 );
     QFont t = ui->labelDT->font();
-    t.setPointSize( t.pointSize() - 3 );
+    t.setPointSize( t.pointSize() - 1 );
 
+    qDebug("Set Font Sizes");
+    //Set Font Sizes
+    ui->labelStat->setFont(f);
+    ui->labelLocStat->setFont(g);
+    ui->labelDT->setFont(t);
+
+    qDebug("Set Date Time Text");
     //Set Date Time Text
    if ( QFileInfo("/tmp/flopswapcur").exists() )
     {
+       qDebug(">flopswapcur exists");
         QSettings settings("flopswap", "flopswap");
-        if (settings.contains("LastRefreshDateTime"))
-        {
-          ui->labelDT->setText("Updated: " + settings.value("LastRefreshDateTime").toString());
-        }
-        else
-        {
-          ui->labelDT->setText("");
-        }
+        ssc = settings.value("StartupCheck").toBool();
+       if (ssc == false)
+       {
+           qDebug(">>startcheck is false");
+           if ( QFileInfo("/tmp/flopswaploc").exists() )
+           {
+              qDebug(">>>If flopswaploc exists");
+              QFile file("/tmp/flopswaploc");
+              file.open(QIODevice::ReadOnly | QIODevice::Text);
+              QTextStream in(&file);
+              QString line = in.readLine();
+              ui->labelLocStat->setText(line);
+           }
+           else
+           {
+              qDebug(">>>flopswaploc didn't exist");
+              ui->labelLocStat->setText("Initialized...");
+           }
+
+           QFile file("/tmp/flopswapcur");
+           file.open(QIODevice::ReadOnly | QIODevice::Text);
+           QTextStream in(&file);
+           QString line = in.readLine();
+           ui->labelStat->setText(line);
+
+           QSettings settings("flopswap", "flopswap");
+           QString dts = settings.value("LastRefreshDateTime").toString();
+           ui->labelDT->setText("Updated: " + dts);
+       }
+       else
+       {
+           qDebug(">>startcheck is true");
+           ui->pushButtonGet->click();
+       }
     }
    else
     {
+       qDebug(">flopswapcur didn't exist");
        ui->labelDT->setText("Updated: Never");
     }
 
+    qDebug("Set Action Text");
     //Set Action Text
     ui->actionSettings->setText(tr("Settings"));
     ui->actionReadme->setText(tr("Quick Guide"));
     ui->actionHelp->setText(tr("Help"));
     ui->actionAbout->setText(tr("About"));
 
+    qDebug("Set Actions");
     //Set Actions
     about = new About(this);
     help = new Help(this);
     instructions = new Instructions(this);
     settingspage = new Settings(this);
 
+    qDebug("Keyboard Buttons");
     //For Connecting Keyboard Buttons
     connectSignals();
 
+    qDebug("Initial Text");
     //Initial Text - Show Once
     initialshow();
 
+    qDebug("Initial QSettings");
     //Initial QSettings for Spin Box
     initialpsb();
 
+    qDebug("Button Disable");
     //Check for existance of /tmp/flopswapint for button disable
     disableStatus();
 
+    qDebug("Progress Indication");
     //Check for existance of /tmp/flopswapref for progress indication
     swappingActive();
 
-    //Check QSettings for Startup Check option
-    if (settingspage->startupCheck())
-    {
-        //If true click immediately after initialization
-        ui->pushButtonGet->click();
-    }
-
+    qDebug("Connect Slots");
     //GUI Blocking on Swap
     connect(m_process, SIGNAL(started()), this, SLOT(disableButtons()));
     connect(m_process, SIGNAL(finished(int,QProcess::ExitStatus)), this, SLOT(enableButtons()));
 
+    qDebug("Construction Done!");
+
 }
 
 MainWindow::~MainWindow()
@@ -190,7 +231,6 @@ void MainWindow::connectSignals()
     connect(new QShortcut(QKeySequence(Qt::Key_Q), this), SIGNAL(activated()), this, SLOT(on_pushButtonSwap_clicked()));
     connect(new QShortcut(QKeySequence(Qt::Key_W), this), SIGNAL(activated()), this, SLOT(on_pushButtonEject_clicked()));
     connect(new QShortcut(QKeySequence(Qt::Key_A), this), SIGNAL(activated()), this, SLOT(on_pushButtonGet_clicked()));
-    //connect(new QShortcut(QKeySequence(Qt::Key_S), this), SIGNAL(activated()), this, SLOT(on_pushButtonSwapUsage_clicked()));
 }
 
 //Portrait switch
@@ -284,7 +324,7 @@ void MainWindow::ejectseen()
 //Check for existance of /tmp/flopswapint to disable Buttons
 void MainWindow::disableStatus()
 {
- if ( QFileInfo("/tmp/flopswapint").exists() )
+   if ( QFileInfo("/tmp/flopswapint").exists() )
    {
         ui->pushButtonEject->setDisabled(true);
         ui->pushButtonEjectV->setDisabled(true);
@@ -292,36 +332,11 @@ void MainWindow::disableStatus()
         ui->labelStat->setText("Not Available");
         ui->labelLocStat->setText("Safe to Remove Back Cover");
    }
- else
+   else
    {
         ui->pushButtonEject->setDisabled(false);
         ui->pushButtonEjectV->setDisabled(false);
         ui->pushButtonGet->setDisabled(false);
-          if ( QFileInfo("/tmp/flopswapcur").exists() )
-          {
-              QFile file("/tmp/flopswapcur");
-              file.open(QIODevice::ReadOnly | QIODevice::Text);
-              QTextStream in(&file);
-              QString line = in.readLine();
-              ui->labelStat->setText(line);
-          }
-          else
-          {
-              ui->labelStat->setText("Initialized...");
-          }
-          if ( QFileInfo("/tmp/flopswaploc").exists() )
-          {
-              QFile file("/tmp/flopswaploc");
-              file.open(QIODevice::ReadOnly | QIODevice::Text);
-              QTextStream in(&file);
-              QString line = in.readLine();
-              ui->labelLocStat->setText(line);
-          }
-          else
-          {
-              ui->labelLocStat->setText("Initialized...");
-              ui->pushButtonGet->click();
-          }
    }
 }
 
@@ -348,7 +363,6 @@ void MainWindow::disableButtons()
     ui->pushButtonEject->setDisabled(true);
     ui->pushButtonEjectV->setDisabled(true);
     ui->pushButtonGet->setDisabled(true);
-    //ui->pushButtonSwapUsage->setDisabled(true);
 }
 
 //Use to enable Buttons on QProcess complete
@@ -359,7 +373,6 @@ void MainWindow::enableButtons()
     ui->pushButtonEject->setDisabled(false);
     ui->pushButtonEjectV->setDisabled(false);
     ui->pushButtonGet->setDisabled(false);
-    //ui->pushButtonSwapUsage->setDisabled(false);
     disableStatus();
 }
 
@@ -386,10 +399,49 @@ void MainWindow::ejectclick()
      }
 }
 
+void MainWindow::updatestatus()
+{
+    if ( QFileInfo("/tmp/flopswaploc").exists() )
+    {
+       QFile file("/tmp/flopswaploc");
+       file.open(QIODevice::ReadOnly | QIODevice::Text);
+       QTextStream in(&file);
+       QString line = in.readLine();
+       ui->labelLocStat->setText(line);
+    }
+    else
+    {
+       ui->labelLocStat->setText("Initialized...");
+    }
+
+     if ( QFileInfo("/tmp/flopswapcur").exists() )
+     {
+        QFile file("/tmp/flopswapcur");
+        file.open(QIODevice::ReadOnly | QIODevice::Text);
+        QTextStream in(&file);
+        QString line = in.readLine();
+        ui->labelStat->setText(line);
+     }
+     else
+     {
+        ui->labelStat->setText("Initialized...");
+     }
+
+    QDateTime dateTime = QDateTime::currentDateTime();
+    QString dateTimeString = dateTime.toString();
+    ui->labelDT->setText("Updated: " + dateTimeString);
+    QSettings settings("flopswap", "flopswap");
+    settings.setValue("LastRefreshDateTime", dateTimeString);
+}
+
 //Buttons
 void MainWindow::on_pushButtonSwap_clicked()
 { 
     m_process->start("sudo /opt/flopswap/script/swapswitch.sh");
+
+    m_process->waitForFinished();
+
+    updatestatus();
 }
 
 void MainWindow::on_pushButtonEject_clicked()
@@ -405,18 +457,12 @@ void MainWindow::on_pushButtonEjectV_clicked()
 void MainWindow::on_pushButtonGet_clicked()
 {
     m_process->start("sudo /opt/flopswap/script/swapused.sh");
-    QDateTime dateTime = QDateTime::currentDateTime();
-    QString dateTimeString = dateTime.toString();
-    ui->labelDT->setText("Updated: " + dateTimeString);
-    QSettings settings("flopswap", "flopswap");
-    settings.setValue("LastRefreshDateTime", dateTimeString);
+
+    m_process->waitForFinished();
+
+    updatestatus();
 }
-/*
-void MainWindow::on_pushButtonSwapUsage_clicked()
-{
-    m_process->start("sudo /opt/flopswap/script/swapused.sh");
-}
-*/
+
 //Actions
 void MainWindow::on_actionAbout_triggered()
 {
