@@ -49,8 +49,6 @@ private slots:
 
     void on_pushButtonGet_clicked();
 
-    //void on_pushButtonSwapUsage_clicked();
-
     void on_actionAbout_triggered();
 
     void on_actionHelp_triggered();
@@ -79,9 +77,12 @@ private slots:
 
     void enableButtons();
 
+    void updatestatus();
+
 private:
     Ui::MainWindow *ui;
     bool portrait;
+    bool ssc;
     About *about;
     Help *help;
     Instructions *instructions;
