@@ -3,6 +3,8 @@
 source /opt/flopswap/script/setvari.sh
 
 echo $swap
+#Print to file
+echo $swap > "$locatetempfile"
 banner "$swap"
  if [ "$swap" = "$swap1" ] ;
   then
