@@ -74,4 +74,5 @@ echo $ublocks ublocks
 umbytes=$(($ublocks/2048))
 ########################
 echo $umbytes umbytes
-echo "$umbytes" > /tmp/flopswaplast && exit 1
+echo "$umbytes" > /tmp/flopswaplast 
+sleep 5 && exit 1
